@@ -48,7 +48,7 @@ my $_CHECK = {
 	'uid'		=> sub { return if not defined $_[0] or $_[0] !~ /^[0-9]+$/o; TRUE },
 	'home'		=> sub { return if not defined $_[0] or $_[0] !~ PATH; TRUE },
 	'shell'		=> sub { return if not defined $_[0] or $_[0] !~ PATH; TRUE },
-	'gecos'		=> sub { return if not defined $_[0] or $_[0] !~ /^[^:]*$/o; TRUE },
+	'gecos'		=> sub { return if not defined $_[0] or $_[0] !~ /^[^:\r\n]*$/o; TRUE },
 	'passwd' 	=> sub { return if not defined $_[0]; TRUE},
 };
 #======================================================================
@@ -882,7 +882,7 @@ Passwd::Unix::Alt - Manipulate /etc/{passwd,shadow,group,gshadow} entries
 
 =head1 VERSION
 
-version 0.5204
+version 0.5205
 
 =head1 SYNOPSIS
 
